==> aTunes_1.9.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/controllers/navigation/listeners/NavigationTreeToolTipListener.java <==
/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.controllers.navigation.listeners;

import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionListener;
import java.awt.event.MouseWheelEvent;
import java.awt.event.MouseWheelListener;
import java.util.concurrent.ExecutionException;

import javax.swing.ImageIcon;
import javax.swing.SwingWorker;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.TreePath;

import net.sourceforge.atunes.Constants;
import net.sourceforge.atunes.gui.views.panels.NavigationPanel;
import net.sourceforge.atunes.kernel.Kernel;
import net.sourceforge.atunes.kernel.controllers.navigation.NavigationController;
import net.sourceforge.atunes.kernel.modules.repository.model.Album;
import net.sourceforge.atunes.utils.LanguageTool;
import net.sourceforge.atunes.utils.StringUtils;
import net.sourceforge.atunes.utils.log4j.LogCategories;
import net.sourceforge.atunes.utils.log4j.Logger;

/**
 * The listener interface for receiving navigationTreeToolTip events.
 */
public class NavigationTreeToolTipListener implements MouseMotionListener, MouseWheelListener {

	/** The Constant logger. */
	static final Logger logger = new Logger();

	/** The controller. */
	NavigationController controller;

	/** The panel. */
	private NavigationPanel panel;

	/** The album. */
	Album album;

	/**
	 * Instantiates a new navigation tree tool tip listener.
	 * 
	 * @param controller
	 *            the controller
	 * @param panel
	 *            the panel
	 */
	public NavigationTreeToolTipListener(NavigationController controller, NavigationPanel panel) {
		this.controller = controller;
		this.panel = panel;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.MouseMotionListener#mouseDragged(java.awt.event.MouseEvent)
	 */
	@Override
	public void mouseDragged(@SuppressWarnings("unused")
	MouseEvent arg0) {
		if (!Kernel.getInstance().state.isShowAlbumTooltip())
			return;

		controller.setLastAlbumToolTipContent(null);
		controller.getAlbumToolTip().setVisible(false);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.MouseMotionListener#mouseMoved(java.awt.event.MouseEvent)
	 */
	@SuppressWarnings("boxing")
	@Override
	public void mouseMoved(MouseEvent e) {
		if (!Kernel.getInstance().state.isShowAlbumTooltip())
			return;

		TreePath selectedPath = panel.getRepositoryTree().getPathForLocation(e.getX(), e.getY());
		if (selectedPath != null) {
			DefaultMutableTreeNode node = (DefaultMutableTreeNode) selectedPath.getLastPathComponent();
			final Object content = node.getUserObject();

			if (content instanceof Album) {
				album = (Album) content;
				if (!controller.getAlbumToolTip().isVisible() || controller.getLastAlbumToolTipContent() == null || controller.getLastAlbumToolTipContent() != content) {
					if (controller.getAlbumToolTip().isVisible())
						controller.getAlbumToolTip().setVisible(false);
					controller.getAlbumToolTip().setLocation((int) panel.getRepositoryTree().getLocationOnScreen().getX() + e.getX(),
							(int) panel.getRepositoryTree().getLocationOnScreen().getY() + e.getY() + 20);
					new SwingWorker<ImageIcon, Void>() {
						@Override
						protected ImageIcon doInBackground() throws Exception {
							return ((Album) content).getPicture(Constants.TOOLTIP_IMAGE_WIDTH, Constants.TOOLTIP_IMAGE_HEIGHT);
						}

						@Override
						protected void done() {
							try {
								if (album.equals(content)) {
									controller.getAlbumToolTip().setPicture(get());
								}
							} catch (InterruptedException e1) {
								logger.error(LogCategories.IMAGE, e1);
							} catch (ExecutionException e1) {
								logger.error(LogCategories.IMAGE, e1);
							}
						}
					}.execute();
					controller.getAlbumToolTip().setAlbum(((Album) content).getName());
					controller.getAlbumToolTip().setArtist(((Album) content).getArtist().toString());
					int songs = ((Album) content).getAudioObjects().size();
					controller.getAlbumToolTip().setSongs(StringUtils.getString(songs, " ", (songs > 1 ? LanguageTool.getString("SONGS") : LanguageTool.getString("SONG"))));
					controller.setLastAlbumToolTipContent(content);

					controller.getAlbumToolTip().timer.setInitialDelay(Kernel.getInstance().state.getAlbumTooltipDelay() * 1000);
					controller.getAlbumToolTip().timer.setRepeats(false);
					controller.getAlbumToolTip().timer.start();
				}
			} else {
				controller.setLastAlbumToolTipContent(null);
				controller.getAlbumToolTip().setVisible(false);
				controller.getAlbumToolTip().timer.stop();
			}
		} else {
			controller.getAlbumToolTip().setVisible(false);
			controller.getAlbumToolTip().timer.stop();
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.MouseWheelListener#mouseWheelMoved(java.awt.event.MouseWheelEvent)
	 */
	@Override
	public void mouseWheelMoved(@SuppressWarnings("unused")
	MouseWheelEvent e) {
		if (!Kernel.getInstance().state.isShowAlbumTooltip())
			return;

		controller.setLastAlbumToolTipContent(null);
		controller.getAlbumToolTip().setVisible(false);
	}

}

==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/controllers/navigation/listeners/NavigationTreeToolTipListener.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.controllers.navigation.listeners;

import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionListener;
import java.awt.event.MouseWheelEvent;
import java.awt.event.MouseWheelListener;

import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.TreePath;

import net.sourceforge.atunes.gui.views.panels.NavigationPanel;
import net.sourceforge.atunes.kernel.Kernel;
import net.sourceforge.atunes.kernel.controllers.navigation.NavigationController;
import net.sourceforge.atunes.kernel.modules.repository.model.Album;
import net.sourceforge.atunes.utils.LanguageTool;
import net.sourceforge.atunes.utils.StringUtils;
import net.sourceforge.atunes.utils.log4j.Logger;

/**
 * The listener interface for receiving navigationTreeToolTip events.
 */
public class NavigationTreeToolTipListener implements MouseMotionListener, MouseWheelListener {

	/** The Constant logger. */
	static final Logger logger = new Logger();

	/** The controller. */
	NavigationController controller;

	/** The panel. */
	private NavigationPanel panel;

	/** The album. */
	Album album;

	/**
	 * Instantiates a new navigation tree tool tip listener.
	 * 
	 * @param controller
	 *            the controller
	 * @param panel
	 *            the panel
	 */
	public NavigationTreeToolTipListener(NavigationController controller, NavigationPanel panel) {
		this.controller = controller;
		this.panel = panel;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * java.awt.event.MouseMotionListener#mouseDragged(java.awt.event.MouseEvent
	 * )
	 */
	@Override
	public void mouseDragged(MouseEvent arg0) {
		if (!Kernel.getInstance().state.isShowAlbumTooltip()) {
			return;
		}

		controller.setCurrentAlbumToolTipContent(null);
		controller.getAlbumToolTip().setVisible(false);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * java.awt.event.MouseMotionListener#mouseMoved(java.awt.event.MouseEvent)
	 */
	@Override
	public void mouseMoved(MouseEvent e) {
		if (!Kernel.getInstance().state.isShowAlbumTooltip()) {
			return;
		}

		TreePath selectedPath = panel.getRepositoryTree().getPathForLocation(e.getX(), e.getY());
		if (selectedPath != null) {
			DefaultMutableTreeNode node = (DefaultMutableTreeNode) selectedPath.getLastPathComponent();
			final Object content = node.getUserObject();

			if (content.equals(album)) {
				return;
			}

			if (content instanceof Album) {
				album = (Album) content;
				if (!controller.getAlbumToolTip().isVisible() || controller.getCurrentAlbumToolTipContent() == null || controller.getCurrentAlbumToolTipContent() != content) {
					if (controller.getAlbumToolTip().isVisible()) {
						controller.getAlbumToolTip().setVisible(false);
					}
					controller.getAlbumToolTip().setLocation((int) panel.getRepositoryTree().getLocationOnScreen().getX() + e.getX(),
							(int) panel.getRepositoryTree().getLocationOnScreen().getY() + e.getY() + 20);

					controller.getAlbumToolTip().setAlbum(((Album) content).getName());
					controller.getAlbumToolTip().setArtist(((Album) content).getArtist().toString());
					int songs = ((Album) content).getAudioObjects().size();
					controller.getAlbumToolTip().setSongs(StringUtils.getString(songs, " ", (songs > 1 ? LanguageTool.getString("SONGS") : LanguageTool.getString("SONG"))));
					controller.setCurrentAlbumToolTipContent(content);
					controller.getAlbumToolTip().setPicture(null);

					controller.getToolTipTimer().setInitialDelay(Kernel.getInstance().state.getAlbumTooltipDelay() * 1000);
					controller.getToolTipTimer().setRepeats(false);
					controller.getToolTipTimer().start();
				}
			} else {
				controller.setCurrentAlbumToolTipContent(null);
				controller.getAlbumToolTip().setVisible(false);
				controller.getToolTipTimer().stop();
			}
		} else {
			controller.getAlbumToolTip().setVisible(false);
			controller.getToolTipTimer().stop();
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seejava.awt.event.MouseWheelListener#mouseWheelMoved(java.awt.event.
	 * MouseWheelEvent)
	 */
	@Override
	public void mouseWheelMoved(MouseWheelEvent e) {
		if (!Kernel.getInstance().state.isShowAlbumTooltip()) {
			return;
		}

		controller.setCurrentAlbumToolTipContent(null);
		controller.getAlbumToolTip().setVisible(false);
	}

}
